@@ -1,9 +1,10 @@
 import json
 from haversine import haversine, Unit
-import importlib.resources
+from .airports import airports
 
-with importlib.resources.path("Flighter", "airports.json") as data_file:
-    data = json.load(data_file)  
+f = airports()
+
+data = json.loads(f)
 
 class Flighter:
   def __init__(self, plane=None, speed=0, icao1=None, icao2=None):
