@@ -5,7 +5,7 @@ with open("Flighter/README.md", "r") as fh:
 
 setuptools.setup(
     name="Flighter", # Replace with your own username
-    version="1.1.5",
+    version="2.0.0",
     author="CoolJames1610",
     author_email="jadokofie@gmail.com",
     description="Flighter is an easy-to-use Python module that allows users to explore aviation using Python",
@@ -13,7 +13,6 @@ setuptools.setup(
     long_description_content_type="text/markdown",
     url="https://github.com/CoolJames1610/Flighter",
     packages=setuptools.find_packages(),
-    package_data={'airports.json': ['*.json', 'Flighter/airports.json']},
     include_package_data=True,
     classifiers=[
         "Programming Language :: Python :: 3",
@@ -25,5 +24,4 @@ setuptools.setup(
     install_requires=[            
           'haversine'
       ],
-    data_files=[('Flighter', ['Flighter/airports.json'])]
 )
\ No newline at end of file
